==> unico_device_setuper-0.12.1-py3-none-any.whl: unico_device_setuper/lib/unitech/impl/models/register_device_payload.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="RegisterDevicePayload")


@_attrs_define
class RegisterDevicePayload:
    """
    Attributes:
        name (str):  Example: string.
        iDevice (str):  Example: string.
    """

    name: str
    idDevice: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        idDevice = self.idDevice

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "idDevice": idDevice,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        idDevice = d.pop("idDevice")

        register_device_payload = cls(
            name=name,
            idDevice=idDevice,
        )

        register_device_payload.additional_properties = d
        return register_device_payload

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> unico_device_setuper-1.13.0-py3-none-any.whl: unico_device_setuper/lib/unitech/impl/models/register_device_payload.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="RegisterDevicePayload")


@_attrs_define
class RegisterDevicePayload:
    """
    Attributes:
        name (str):  Example: string.
        id_device (str):  Example: string.
    """

    name: str
    id_device: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        id_device = self.id_device

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "idDevice": id_device,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        id_device = d.pop("idDevice")

        register_device_payload = cls(
            name=name,
            id_device=id_device,
        )

        register_device_payload.additional_properties = d
        return register_device_payload

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
